@@ -1,5 +1,7 @@
 """Create a tmux workspace from a workspace :py:obj:`dict`."""
 
+from __future__ import annotations
+
 import logging
 import os
 import shutil
@@ -16,6 +18,9 @@ from libtmux.window import Window
 from tmuxp import exc
 from tmuxp.util import get_current_pane, run_before_script
 
+if t.TYPE_CHECKING:
+    from collections.abc import Iterator
+
 logger = logging.getLogger(__name__)
 
 COLUMNS_FALLBACK = 80
@@ -143,15 +148,15 @@ class WorkspaceBuilder:
     a session inside tmux (when `$TMUX` is in the env variables).
     """
 
-    server: "Server"
-    _session: t.Optional["Session"]
+    server: Server
+    _session: Session | None
     session_name: str
 
     def __init__(
         self,
-        session_config: t.Dict[str, t.Any],
+        session_config: dict[str, t.Any],
         server: Server,
-        plugins: t.Optional[t.List[t.Any]] = None,
+        plugins: list[t.Any] | None = None,
     ) -> None:
         """Initialize workspace loading.
 
@@ -218,7 +223,7 @@ class WorkspaceBuilder:
             return False
         return True
 
-    def build(self, session: t.Optional[Session] = None, append: bool = False) -> None:
+    def build(self, session: Session | None = None, append: bool = False) -> None:
         """Build tmux workspace in session.
 
         Optionally accepts ``session`` to build with only session object.
@@ -235,9 +240,12 @@ class WorkspaceBuilder:
         """
         if not session:
             if not self.server:
-                raise exc.TmuxpException(
+                msg = (
                     "WorkspaceBuilder.build requires server to be passed "
-                    + "on initialization, or pass in session object to here.",
+                    "on initialization, or pass in session object to here."
+                )
+                raise exc.TmuxpException(
+                    msg,
                 )
             new_session_kwargs = {}
             if "start_directory" in self.session_config:
@@ -271,7 +279,7 @@ class WorkspaceBuilder:
 
         assert session.server is not None
 
-        self.server: "Server" = session.server
+        self.server: Server = session.server
         assert self.server.sessions is not None
         assert self.server.has_session(session.name)
         assert session.id
@@ -302,7 +310,7 @@ class WorkspaceBuilder:
 
         if "global_options" in self.session_config:
             for option, value in self.session_config["global_options"].items():
-                self.session.set_option(option, value, _global=True)
+                self.session.set_option(option, value, global_=True)
 
         if "environment" in self.session_config:
             for option, value in self.session_config["environment"].items():
@@ -343,7 +351,7 @@ class WorkspaceBuilder:
         self,
         session: Session,
         append: bool = False,
-    ) -> t.Iterator[t.Any]:
+    ) -> Iterator[t.Any]:
         """Return :class:`libtmux.Window` iterating through session config dict.
 
         Generator yielding :class:`libtmux.Window` by iterating through
@@ -410,8 +418,11 @@ class WorkspaceBuilder:
                 else:
                     target = "windows"
                 logger.warning(
-                    f"Cannot set environment for new {target}. "
-                    "You need tmux 3.0 or newer for this.",
+                    (
+                        "Cannot set environment for new %s. "
+                        "You need tmux 3.0 or newer for this."
+                    ),
+                    target,
                 )
                 environment = None
 
@@ -443,8 +454,8 @@ class WorkspaceBuilder:
     def iter_create_panes(
         self,
         window: Window,
-        window_config: t.Dict[str, t.Any],
-    ) -> t.Iterator[t.Any]:
+        window_config: dict[str, t.Any],
+    ) -> Iterator[t.Any]:
         """Return :class:`libtmux.Pane` iterating through window config dict.
 
         Run ``shell_command`` with ``$ tmux send-keys``.
@@ -479,9 +490,9 @@ class WorkspaceBuilder:
             else:
 
                 def get_pane_start_directory(
-                    pane_config: t.Dict[str, str],
-                    window_config: t.Dict[str, str],
-                ) -> t.Optional[str]:
+                    pane_config: dict[str, str],
+                    window_config: dict[str, str],
+                ) -> str | None:
                     if "start_directory" in pane_config:
                         return pane_config["start_directory"]
                     if "start_directory" in window_config:
@@ -489,9 +500,9 @@ class WorkspaceBuilder:
                     return None
 
                 def get_pane_shell(
-                    pane_config: t.Dict[str, str],
-                    window_config: t.Dict[str, str],
-                ) -> t.Optional[str]:
+                    pane_config: dict[str, str],
+                    window_config: dict[str, str],
+                ) -> str | None:
                     if "shell" in pane_config:
                         return pane_config["shell"]
                     if "window_shell" in window_config:
@@ -565,7 +576,7 @@ class WorkspaceBuilder:
     def config_after_window(
         self,
         window: Window,
-        window_config: t.Dict[str, t.Any],
+        window_config: dict[str, t.Any],
     ) -> None:
         """Actions to apply to window after window and pane finished.
 
